# always_updates

always_updates updates your system. always_updates will always update, even
if other packages on your system do not have updates available.


## installation
```
pip install always-updates
```

## usage
```
aupd
```
